<div class="header"><?php MenuFormlet::show() ?></div>

<h1>ڡ</h1>
<?php AllPagesFormlet::show() ?>
<p></p>
